/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2006 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Sam Lantinga
    slouken@libsdl.org
*/
#include "SDL_config.h"

#include "SDL.h"
#include "../../events/SDL_sysevents.h"
#include "../../events/SDL_events_c.h"

#include "SDL_iphonevideo.h"
#include "SDL_iphoneevents.h"

#import <UIKit/UIKit.h>

void iPhone_PumpEvents(_THIS)
{
	NSArray* events = [[UIApp getView] getEvents];
	if(events == nil) return;
	
	NSEnumerator* enumerator = [events objectEnumerator];
	id event;
	 
	while(event = [enumerator nextObject])
	{
		id type = [event objectForKey:@"type"];
		if(type == nil) continue;
		
		if([type isEqualToString:@"mouseDown"]) {
			SDL_PrivateMouseButton (SDL_PRESSED, SDL_BUTTON_LEFT, [[event objectForKey:@"x"] intValue], [[event objectForKey:@"y"] intValue]);
		}
		else if([type isEqualToString:@"mouseUp"]) {
			SDL_PrivateMouseButton (SDL_RELEASED, SDL_BUTTON_LEFT, [[event objectForKey:@"x"] intValue], [[event objectForKey:@"y"] intValue]);
		}
		else if([type isEqualToString:@"mouseDragged"]) {
			SDL_PrivateMouseMotion (0, 0, [[event objectForKey:@"x"] intValue], [[event objectForKey:@"y"] intValue]);
		}
		else if([type isEqualToString:@"mouseMoved"]) {
			SDL_PrivateMouseMotion (0, 0, [[event objectForKey:@"x"] intValue], [[event objectForKey:@"y"] intValue]);
		}
		else if([type isEqualToString:@"keyDown"]) {
			SDL_keysym keysym;
			SDLKey key = (SDLKey)[[event objectForKey:@"key"] intValue];
			keysym.sym = keysym.unicode = key;
			keysym.mod = 0;
			keysym.scancode = 0xff;
			SDL_PrivateKeyboard(SDL_PRESSED, &keysym);
		}
		else if([type isEqualToString:@"keyUp"]) {
			SDL_keysym keysym;
			SDLKey key = (SDLKey)[[event objectForKey:@"key"] intValue];
			keysym.sym = keysym.unicode = key;
			keysym.mod = 0;
			keysym.scancode = 0xff;
			SDL_PrivateKeyboard(SDL_RELEASED, &keysym);
		}
	}
}

void iPhone_InitOSKeymap(_THIS)
{
}

