/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2006 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Sam Lantinga
    slouken@libsdl.org
*/
#include "SDL_config.h"

#ifndef _SDL_iphonevideo_h
#define _SDL_iphonevideo_h

#include "../SDL_sysvideo.h"

#import <UIKit/UIKit.h>
#import <UIKit/UIView-Geometry.h>
#import <GraphicsServices/GraphicsServices.h>
#import <Foundation/Foundation.h>
#import <CoreSurface/CoreSurface.h>
#import <LayerKit/LKLayer.h>


@interface SDL_iPhoneView : UIView
{
	NSMutableArray* _events;
	NSLock* _lock;
	LKLayer* _screenLayer;
	CoreSurfaceBufferRef _screenSurface;
	
	CGRect _frameRect;
	CGSize _screenSize;
}

- (id)initWithFrame:(struct CGRect)frame;
- (void)setScreenSize:(NSDictionary*)size;

- (void)lock;
- (void)unlock;

- (void)addEvent:(NSDictionary*)event;
- (NSArray*)getEvents;

- (void)gestureChanged:(GSEvent*)event;
- (void)gestureEnded:(GSEvent*)event;
- (void)gestureStarted:(GSEvent*)event;
- (void)keyDown:(GSEvent*)event;	
- (void)keyUp:(GSEvent*)event;
- (void)mouseMoved:(GSEvent*)event;	
- (void)mouseDown:(GSEvent*)event;
- (void)mouseUp:(GSEvent*)event;	
- (void)mouseDragged:(GSEvent*)event;	
- (void)mouseEntered:(GSEvent*)event;	
- (void)mouseExited:(GSEvent*)event;	

- (void)drawRect:(CGRect)frame;

- (CoreSurfaceBufferRef)getSurface;

@end

#define _THIS	SDL_VideoDevice *this

typedef struct SDL_PrivateVideoData 
{
	SDL_iPhoneView* _view;
} SDL_PrivateVideoData;

#endif /* _SDL_nullvideo_h */
