/*

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; version 2
 of the License.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#include "iphoneInterface.h"

#import "FileBrowser.h"
#import <UIKit/UISimpleTableCell.h>
#define MAXPATHLEN 512

@implementation FileBrowser 
- (id)initWithFrame:(struct CGRect)frame{
	if ((self == [super initWithFrame: frame]) != nil) {
	
		CGRect navRect = CGRectMake(0,0,frame.size.width,NAVBARHEIGHT);
		//NavBarを作成
		_navBar = [[UINavigationBar alloc] initWithFrame:navRect];
		[_navBar enableAnimation];
		[_navBar setDelegate:self];
		//[_navBar setItemDelegate:self];

		//NavItemを作成
		UINavigationItem* navItem = [[UINavigationItem alloc] initWithTitle:NSLocalizedString(@"File Select",@"")];
		[_navBar pushNavigationItem:navItem];
		[_navBar showLeftButton:NSLocalizedString(@"Cancel", nil) withStyle:0 rightButton:NSLocalizedString(@"OK", nil) withStyle:3];
		[self addSubview: _navBar];


		UITableColumn *col = [[UITableColumn alloc]
			initWithTitle: @"FileName"
			identifier:@"filename"
			width: frame.size.width
		];
		_table = [[UITable alloc] initWithFrame: CGRectMake(0, NAVBARHEIGHT, frame.size.width, frame.size.height - NAVBARHEIGHT)];
		[_table addTableColumn: col];
		[_table setSeparatorStyle: 1];
		[_table setDelegate: self];
		[_table setDataSource: self];
		_extensions = [[NSMutableArray alloc] init];
		_files = [[NSMutableArray alloc] init];
		_rowCount = 0;
		_delegate = nil;
		[self addSubview: _table];
	}

	return self;
}

- (void)dealloc {
	[_path release];
	[_files release];
	[_extensions release];
	[_table release];
	_delegate = nil;
	[super dealloc];
}

- (NSString *)path {
	return [[_path retain] autorelease];
}

- (void)setPath: (NSString *)path {
	[_path release];
	_path = [path copy];

	[self reloadData];
}

- (void)addExtension: (NSString *)extension {
	if (![_extensions containsObject:[extension lowercaseString]]) {
		[_extensions addObject: [extension lowercaseString]];
	}
}

- (void)setExtensions: (NSArray *)extensions {
	[_extensions setArray: extensions];
}

- (void)reloadData {
        BOOL isDir;
	NSFileManager *fileManager = [NSFileManager defaultManager];
	NSArray *tempArray = [[NSArray alloc] initWithArray:[fileManager directoryContentsAtPath:_path]];

	if ([fileManager fileExistsAtPath: _path] == NO) {
		return;
	}

	[_files removeAllObjects];
		
        NSString *file;
        file = @"[NO SELECT]";
        [_files addObject: file];
        NSEnumerator *dirEnum = [tempArray objectEnumerator];
	while (file = [dirEnum nextObject]) {
		if (_extensions != nil && [_extensions count] > 0) {
			NSString *extension = [[file pathExtension] lowercaseString];
			if ([_extensions containsObject: extension]) {
				[_files addObject: file];
			}
		} else {
			[_files addObject: file];
		}
 	}

	//[_files sortUsingSelector:@selector(caseInsensitiveCompare:)];
	_rowCount = [_files count];
	[_table reloadData];
	[tempArray release];
}

- (void)setDelegate:(id)delegate {
	_delegate = delegate;
}

- (int)numberOfRowsInTable:(UITable *)table {
	return _rowCount;
}


- (UITableCell *)table:(UITable *)table cellForRow:(int)row column:(UITableColumn *)col {
        BOOL isDir = NO;
        char buf0[MAXPATHLEN];
        
	UIImageAndTextTableCell *cell = [[UIImageAndTextTableCell alloc] init];
	[cell setTitle: [_files objectAtIndex: row] ];//stringByDeletingPathExtension]];
	NSString* path0 = [_path copy];
	if([_path characterAtIndex: [_path length] - 1] != '/')
	{
		path0 = [_path stringByAppendingString: @"/"];
	}
	return cell;
}


- (void)tableRowSelected:(NSNotification *)notification {
//	NSLog([self selectedFile]);
//	if( [_delegate respondsToSelector:@selector( fileBrowser:fileSelected: )] )
//		[_delegate fileBrowser:self fileSelected:[self selectedFile]];
}

- (NSString *)selectedFile {
	if ([_table selectedRow] == -1)
		return nil;
	
	return [_files objectAtIndex: [_table selectedRow]] ;
}

//------------------------delegate
- (void)navigationBar:(UINavigationBar*)navBar buttonClicked:(int)button
{
	if(button == 1)
	{
		if( [_delegate respondsToSelector:@selector( EndSelectFile:done: )] )
		{	
			[_delegate EndSelectFile:self done:0];
		}

	}
	else
	{
		if( [_delegate respondsToSelector:@selector( EndSelectFile:done: )] )
		{	
			[_delegate EndSelectFile:self done:1];
		}
	}
}



@end


